@@ -5,11 +5,13 @@ import click
 
 from sym.cli.helpers.ec2.factory import get_ec2_client
 
-from ..decorators import loses_interactivity, require_bins, require_login
+from ..data.request_data import RequestData
+from ..decorators import command_require_bins, loses_interactivity, require_login
 from ..helpers.global_options import GlobalOptions
 from ..helpers.keywords_to_options import keywords_to_options
 from ..helpers.options import resource_argument
 from ..helpers.ssh import raw_ssh, start_ssh_session
+from ..saml_clients.saml_client_factory import SAMLClientFactory
 from .sym import sym
 
 SSH_MAN = """
@@ -179,9 +181,9 @@ def encode_options(kv):
 @click.argument("destination", required=False)
 @click.argument("command", nargs=-1, required=False)
 @click.make_pass_decorator(GlobalOptions)
-@loses_interactivity
-@require_bins("aws", "session-manager-plugin", "ssh")
+@command_require_bins("aws", "session-manager-plugin", "ssh")
 @require_login
+@loses_interactivity
 def ssh(
     options: GlobalOptions,
     resource: str,
@@ -214,10 +216,13 @@ def ssh(
         raw_ssh({"p": str(port)}, *ssh_args)
         return
 
-    client = options.create_saml_client(resource)
+    request_data = RequestData("ssh", resource, options)
+
+    client = SAMLClientFactory.create_saml_client(resource, options)
+
     client.dprint(f"ssh: args={ssh_args}")
     instance = get_ec2_client(client).load_instance_by_alias(destination)
-    new_client = client.clone(options=client.options.clone(aws_region=instance.region))
+    new_client = SAMLClientFactory.clone(client, aws_region=instance.region)
     start_ssh_session(
         new_client,
         instance.instance_id,
