@@ -1,15 +1,20 @@
 from contextlib import contextmanager
-from os import fchmod
+from os import fchmod, get_exec_path, symlink
 from pathlib import Path
 from typing import Iterator, Optional, TextIO
 
 from sym.cli.helpers.config import Config
 from sym.cli.helpers.contexts import push_env
+from sym.cli.helpers.os import find_command
 
 
 class Sandbox:
     def __init__(self, path: Path) -> None:
         self.path = path
+        self.exec_path = get_exec_path()
+
+    def link_binary(self, name):
+        symlink(find_command(name, path=self.exec_path), str(self.path / "bin" / name))
 
     def create_binary(self, name, exist_ok=True):
         try:
